#[repr(transparent)]pub struct LACredentialType(pub NSInteger);LAContext only.Expand description
Tuple Fields
0: NSIntegerImplementations
Sourceimpl LACredentialType
impl LACredentialType
Sourcepub const ApplicationPassword: Self
pub const ApplicationPassword: Self
Password provided by application
If not set, LocalAuthentication will ask for the password when necessary. It will use its own user interface depending on the evaluated policy or ACL. Applications can provide the password using the setCredential method. In such case, LocalAuthentication will not show password entry user interface. When entered from the LocalAuthentication user interface, the password is stored as UTF-8 encoded string.
Sourcepub const SmartCardPIN: Self
pub const SmartCardPIN: Self
Smart card PIN provided by application
If not set, LocalAuthentication will ask users for the smart card PIN when necessary. Applications can provide the PIN using setCredential method. In such case, LocalAuthentication will not show the smart card PIN user interface. When entered from the LocalAuthentication user interface, the PIN is stored as UTF-8 encoded string.